// node modules
import React, { useState, FocusEvent, ChangeEvent, FC } from 'react';

// local files
import { useStyles } from './styles';
import { theming } from "../../theme";

export interface InputProps {
    labelClassName: string;
    rootClassName: string;
    inputClassName: string;
    onChange: (e: ChangeEvent) => void;
    value: string | number;
    label?: string;
    disabled: boolean;
    onFocus?: (e: FocusEvent) => void;
    onBlur?: (e: FocusEvent) => void;
    type?: string;
    error?: boolean;
}

export const Input: FC<InputProps> = ({
    error= false,
    type= 'text',
    disabled = false,
    labelClassName,
    rootClassName,
    inputClassName,
    onChange,
    label,
    value,
    onFocus,
    onBlur,
    ...otherProps
}) => {
    const {
        root,
        labelClass,
        active,
        input,
        unlabeled,
        disabledClass,
        errorClass
    } = useStyles({ theme: theming.useTheme() });
    const [activeClass, setActiveClass] = useState(false);
    const [inputValue, setInputValue] = useState(value || '');
    const handleFocus = (e: FocusEvent<HTMLInputElement>) => {
        if(disabled) return;

        setActiveClass(true);

        if (onFocus) {
            onFocus(e)
        }
    }
    const handleBlur = (e: FocusEvent<HTMLInputElement>) => {
        setActiveClass(!!e.target.value)

        if(onBlur) {
            onBlur(e)
        }
    }
    const handleChange = (e: ChangeEvent<HTMLInputElement>) => {
        setInputValue(e.target.value);

        if (onChange) {
            onChange(e)
        }
    }
    const classNameLabel = `${labelClass} ${labelClassName} ${!!inputValue || activeClass ? active : ''}`
    const rootClass = `${root} ${rootClassName} ${disabled ? disabledClass: ''} ${error ? errorClass : '' }`
    const inputClass = `${input} ${!label ? unlabeled : ''}`

    return (
        <div className={rootClass}>
            {label && <span className={classNameLabel}>{label}</span>}
            <input
                type={type}
                disabled={disabled}
                onBlur={handleBlur}
                onFocus={handleFocus}
                className={inputClass}
                value={inputValue}
                onChange={handleChange}
                {...otherProps}
            />
        </div>
    )
}






