// node modules
import React, { ReactNode, FC } from "react";

// local files
import { useStyles } from "./styles";
import { theming } from "../../theme";

export interface SimpleButtonProps {
    label: string;
    className?: string;
    width?: number;
    disabled?: boolean;
    onClick?: () => void;
    children?: string | ReactNode;
}

export const SimpleButton: FC<SimpleButtonProps> = ({
    className = '',
    label,
    width,
    disabled,
    onClick,
    children,
...otherProps
}) => {
    const { root, disabledClass } = useStyles({ theme: theming.useTheme() });
    const btnClassName = `${root} ${className} ${disabled && disabledClass}`;
    const handleClick = () => {
        if (disabled) return;

        if(onClick) onClick();
    }

    return (
        <button
            onClick={handleClick}
            style={{ width }}
            className={btnClassName}
            {...otherProps}
        >
            {label}
            {children}
        </button>
    )
};
